@@ -65,7 +65,8 @@ class KSCREEN_EXPORT Config : public QObject
         None = 0, ///< None of the mentioned features are supported.
         PrimaryDisplay = 1, ///< The backend knows about the concept of a primary display, this is mostly limited to X11.
         Writable = 1 << 1, ///< The backend supports setting the config, it's not read-only.
-        PerOutputScaling = 1 << 2 ///< The backend supports scaling each output individually.
+        PerOutputScaling = 1 << 2, ///< The backend supports scaling each output individually.
+        OutputReplication = 1 << 3, ///< The backend supports replication of outputs.
     };
     Q_DECLARE_FLAGS(Features, Feature)
 
@@ -115,6 +116,18 @@ class KSCREEN_EXPORT Config : public QObject
      */
     ConfigPtr clone() const;
 
+    /**
+     * Returns an identifying hash for this config in regards to its
+     * connected outputs.
+     *
+     * The hash is calculated with a sorted combination of all
+     * connected output hashes.
+     *
+     * @return sorted hash combination of all connected outputs
+     * @since 5.15
+     */
+    QString connectedOutputsHash() const;
+
     ScreenPtr screen() const;
     void setScreen(const ScreenPtr &screen);
 
@@ -125,7 +138,7 @@ class KSCREEN_EXPORT Config : public QObject
     void setPrimaryOutput(const OutputPtr &output);
     void addOutput(const OutputPtr &output);
     void removeOutput(int outputId);
-    void setOutputs(OutputList outputs);
+    void setOutputs(const OutputList &outputs);
 
     bool isValid() const;
     void setValid(bool valid);
